@@ -43,3 +43,17 @@ fn vec_and_slice_use_element_alignment() {
         <&[TestStruct]>::alignment_in_bytes() as usize
     );
 }
+
+#[test]
+fn arrays_use_element_alignment() {
+    #[derive(Debug, Default, SsbhWrite)]
+    struct TestStruct {
+        x: u8,
+        y: u16,
+    }
+
+    assert_eq!(
+        std::mem::align_of::<TestStruct>(),
+        <[TestStruct; 7]>::alignment_in_bytes() as usize
+    );
+}
